import { IconfontIcon } from "@/icons/fonts/iconfont";
import { Pen } from "@meta2d/core";

export interface IconObject {
  name: IconfontIcon;
  size?: number;
  color?: string;
}

export interface IframeMsg {
  msgType: string;
  [key: string]: any;
}

export interface RegionsPointsItem {
  id: number;
  orgId: number;
  devGroupId: number;
  regionName: string;
  canvas: string;
  outsideDevGroupId: number;
  outsideDevId: number;
  outsideTempParamCode: string;
  outsideHumidityParamCode: string;
  outsideEnthalpyParamCode: string;
  outSideTemperature: string;
  outSideHumidity: string;
  outsideEnthalpy: string;
  avgTemperature: string;
  avgHumidity: string;
  points: MonitoringPointData[];
  name?: string;
}

export interface MonitoringPointData {
  id: number;
  name: string;
  status: number;
  temperature: string;
  humidity: string;
  tempUpper: number;
  tempLower: number;
  humidityUpper: number;
  humidityLower: number;
  tempData: CurvedData[];
  humidityData: CurvedData[];
}

export interface CurvedData {
  time: string;
  value: number;
}

export interface DeviceItem {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  deviceName: string;
  groupId: number;
  deviceType: number;
  userId: number;
  brand: number;
  model: number;
  modelType: number;
  controlType: number;
  compressionLevel: number;
  voltageLevel: number;
  powerRating: number;
  powerUnload: number;
  maximumFlow: number;
  pressure: number;
  pressureMax: number;
  productionDate: string;
  productionNum: string;
  mainTechData: string;
  mountedPosition: string;
  department: string;
  respPerson: string;
  phone: string;
  serviceLife: number;
  status: number;
  remarks: string;
  deleted: number;
  deviceNum: string;
  runningStatus: string;
}

export interface DeviceGroupItem {
  id: number;
  createTime: Date | null;
  updateTime: Date | null;
  createUserId: number | null;
  updateUserId: number | null;
  groupName: string;
  comment: string | null;
  parentId: number;
  userId: number;
  deleted: boolean | null;
  deviceGroupChilds: DeviceGroupChild[];
}

export interface DeviceGroupChild {
  id: number;
  groupName: string;
  comment: string | null;
  parentId: number;
  userId: number;
}

export interface DeviceGroupTree extends DeviceGroupItem {
  label: string;
  children: DeviceGroupTreeChild[];
}

export interface DeviceGroupTreeChild extends DeviceGroupChild {
  label: string;
  children: (DeviceItem & { label: string })[];
}

export interface HvacDevicePen extends Pen {
  hvacDeviceInfo: Partial<DeviceItem>;
  hvacValveType?: number | string;
}