import i18n from '../i18n';

const $t = i18n.global.t;

/**
 * 实时监测和大屏等模块与其可视化 Iframe 内嵌网页通信的消息前缀
 */
export const visual2DMsgPrefix = 'hvac-visual-2d';

/**
 * 实时监测和大屏模块与其可视化 Iframe 内嵌网页通信的消息类型
 */
export const enum Visual2DMsgType {
  EditLoaded = 'edit-loaded',
  CloseEditor = 'close-editor',
  SendDeviceData = 'send-device-data',
  SendDeviceIds = 'send-device-ids',
  SaveModule = 'save-module',
  SaveModuleFailed = 'save-module-failed',
  OpenDevCtrlModal = 'open-dev-ctrl-modal',
  PreviewLoaded = 'preview-loaded',
  PreviewClicked = 'preview-clicked',
  ExportImg = 'export-img',
}

/**
 * 可视化模板类型
 */
export const enum VisualModuleType {
  /**
   * 大屏
   */
  BigScreen,
  /**
   * 2D组态
   */
  Module2D,
  /**
   * 3D组态
   */
  Module3D,
}

export const getVisual2DMsgType = (type: Visual2DMsgType) => {
  return visual2DMsgPrefix + '-' + type;
};

export const enum DeviceType {
  空 = 0,
  控制柜 = 1,
  冷水主机 = 2,
  露点仪 = 3,
  流量计 = 4,
  电表 = 5,
  其他传感器 = 6,
  阀门 = 7,
  循环水泵 = 8,
  冷却塔 = 9,
  风冷模块机组 = 10,
  冷却泵 = 11,
  冷冻泵 = 12,
  热水泵 = 13,
  二次冷冻泵 = 14,
  空调风柜 = 15,
  EC风机 = 16,
  其他设备 = 17,
}

export const enum ValveType {
  冷冻侧阀 = 101,
  冷却侧阀 = 102,
  进口阀 = 103,
  出口阀 = 104,
  旁通阀 = 105,
}

export const valveTypeList = [
  { label: $t("主机冷冻侧阀"), value: ValveType.冷冻侧阀 },
  { label: $t("主机冷却侧阀"), value: ValveType.冷却侧阀 },
  { label: $t("冷却塔进口阀"), value: ValveType.进口阀 },
  { label: $t("冷却塔出口阀"), value: ValveType.出口阀 },
  { label: $t("旁通阀"), value: ValveType.旁通阀 },
];